# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/uom.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/utilities/uom.proto\x12!pro.omni.oms.api.v1.utilities.uom\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xcc\x01\n\x03Uom\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x10\n\x08rounding\x18\x06 \x01(\x01\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x98\x01\n\x10UomCreateRequest\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x10\n\x08rounding\x18\x05 \x01(\x01\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11UomCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03uom\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"\xec\x02\n\x0eUomReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x0fUomReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x34\n\x04uoms\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"\x7f\n\x10UomUpdateRequest\x12\x33\n\x03uom\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11UomUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03uom\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"V\n\x10UomDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11UomDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xee\x03\n\nUomService\x12x\n\tUomCreate\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomCreateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomCreateResponse"\x00\x12r\n\x07UomRead\x12\x31.pro.omni.oms.api.v1.utilities.uom.UomReadRequest\x1a\x32.pro.omni.oms.api.v1.utilities.uom.UomReadResponse"\x00\x12x\n\tUomUpdate\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomUpdateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomUpdateResponse"\x00\x12x\n\tUomDelete\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomDeleteRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.uom_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_UOM"]._serialized_start = 113
    _globals["_UOM"]._serialized_end = 317
    _globals["_UOMCREATEREQUEST"]._serialized_start = 320
    _globals["_UOMCREATEREQUEST"]._serialized_end = 472
    _globals["_UOMCREATERESPONSE"]._serialized_start = 475
    _globals["_UOMCREATERESPONSE"]._serialized_end = 622
    _globals["_UOMREADREQUEST"]._serialized_start = 625
    _globals["_UOMREADREQUEST"]._serialized_end = 989
    _globals["_UOMREADRESPONSE"]._serialized_start = 992
    _globals["_UOMREADRESPONSE"]._serialized_end = 1197
    _globals["_UOMUPDATEREQUEST"]._serialized_start = 1199
    _globals["_UOMUPDATEREQUEST"]._serialized_end = 1326
    _globals["_UOMUPDATERESPONSE"]._serialized_start = 1329
    _globals["_UOMUPDATERESPONSE"]._serialized_end = 1476
    _globals["_UOMDELETEREQUEST"]._serialized_start = 1478
    _globals["_UOMDELETEREQUEST"]._serialized_end = 1564
    _globals["_UOMDELETERESPONSE"]._serialized_start = 1566
    _globals["_UOMDELETERESPONSE"]._serialized_end = 1660
    _globals["_UOMSERVICE"]._serialized_start = 1663
    _globals["_UOMSERVICE"]._serialized_end = 2157
# @@protoc_insertion_point(module_scope)
