# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/delivery_time.proto\x12\'pro.omni.oms.api.v1.rules.delivery_time\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x18v1/rules/warehouse.proto"\xb6\x03\n\x0c\x44\x65liveryTime\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12V\n\x13\x64\x65livery_method_ids\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x45\n\rwarehouse_ids\x18\x04 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x1d\n\x15locality_available_id\x18\x05 \x01(\t\x12\x44\n\ttime_type\x18\x06 \x01(\x0e\x32\x31.pro.omni.oms.api.v1.rules.delivery_time.TimeType\x12\x11\n\tvalue_min\x18\x07 \x01(\t\x12\x11\n\tvalue_max\x18\x08 \x01(\t\x12\x11\n\tinversely\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12?\n\x0cobject_audit\x18\x0b \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xff\x01\n\x19\x44\x65liveryTimeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x02 \x01(\t\x12\x44\n\ttime_type\x18\x03 \x01(\x0e\x32\x31.pro.omni.oms.api.v1.rules.delivery_time.TimeType\x12\x11\n\tvalue_min\x18\x04 \x01(\t\x12\x11\n\tvalue_max\x18\x05 \x01(\t\x12\x11\n\tinversely\x18\x06 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeCreateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17\x44\x65liveryTimeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18\x44\x65liveryTimeReadResponse\x12M\n\x0e\x64\x65livery_times\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19\x44\x65liveryTimeUpdateRequest\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeUpdateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19\x44\x65liveryTimeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44\x65liveryTimeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard*9\n\x08TimeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07MINUTES\x10\x01\x12\t\n\x05HOURS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x32\x97\x05\n\x13\x44\x65liveryTimeService\x12\x9f\x01\n\x12\x44\x65liveryTimeCreate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateResponse"\x00\x12\x99\x01\n\x10\x44\x65liveryTimeRead\x12@.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeUpdate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeDelete\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TIMETYPE"]._serialized_start = 2201
    _globals["_TIMETYPE"]._serialized_end = 2258
    _globals["_DELIVERYTIME"]._serialized_start = 151
    _globals["_DELIVERYTIME"]._serialized_end = 589
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_start = 592
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_end = 847
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_start = 850
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_end = 1031
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_start = 1034
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_end = 1407
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_start = 1410
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_end = 1649
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_start = 1652
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_end = 1813
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_start = 1816
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_end = 1997
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_start = 1999
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_end = 2094
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_start = 2096
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_end = 2199
    _globals["_DELIVERYTIMESERVICE"]._serialized_start = 2261
    _globals["_DELIVERYTIMESERVICE"]._serialized_end = 2924
# @@protoc_insertion_point(module_scope)
