# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"v1/rules/warehouse_hierarchy.proto\x12-pro.omni.oms.api.v1.rules.warehouse_hierarchy\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/location.proto"\xf1\x02\n\x12WarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x41\n\twarehouse\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12>\n\x08location\x18\t \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x19\n\x11quantity_security\x18\x04 \x01(\x02\x12\x10\n\x08sequence\x18\x05 \x01(\x05\x12\x32\n\x0esequence_order\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe5\x01\n\x1fWarehouseHierarchyCreateRequest\x12\x14\n\x0cwarehouse_id\x18\x01 \x01(\t\x12\x13\n\x0blocation_id\x18\x02 \x01(\t\x12\x19\n\x11quantity_security\x18\x03 \x01(\x02\x12\x10\n\x08sequence\x18\x04 \x01(\x05\x12\x32\n\x0esequence_order\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyCreateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfb\x02\n\x1dWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x87\x02\n\x1eWarehouseHierarchyReadResponse\x12_\n\x14warehouses_hierarchy\x18\x01 \x03(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb9\x01\n\x1fWarehouseHierarchyUpdateRequest\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyUpdateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"e\n\x1fWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"m\n WarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x95\x06\n\x19WarehouseHierarchyService\x12\xbd\x01\n\x18WarehouseHierarchyCreate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateResponse"\x00\x12\xb7\x01\n\x16WarehouseHierarchyRead\x12L.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadRequest\x1aM.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyUpdate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyDelete\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_hierarchy_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEHIERARCHY"]._serialized_start = 188
    _globals["_WAREHOUSEHIERARCHY"]._serialized_end = 557
    _globals["_WAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_start = 560
    _globals["_WAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_end = 789
    _globals["_WAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_start = 792
    _globals["_WAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_end = 997
    _globals["_WAREHOUSEHIERARCHYREADREQUEST"]._serialized_start = 1000
    _globals["_WAREHOUSEHIERARCHYREADREQUEST"]._serialized_end = 1379
    _globals["_WAREHOUSEHIERARCHYREADRESPONSE"]._serialized_start = 1382
    _globals["_WAREHOUSEHIERARCHYREADRESPONSE"]._serialized_end = 1645
    _globals["_WAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_start = 1648
    _globals["_WAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_end = 1833
    _globals["_WAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_start = 1836
    _globals["_WAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_end = 2041
    _globals["_WAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_start = 2043
    _globals["_WAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_end = 2144
    _globals["_WAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_start = 2146
    _globals["_WAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_end = 2255
    _globals["_WAREHOUSEHIERARCHYSERVICE"]._serialized_start = 2258
    _globals["_WAREHOUSEHIERARCHYSERVICE"]._serialized_end = 3047
# @@protoc_insertion_point(module_scope)
