# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import stock_move_line_pb2 as v1_dot_stock_dot_stock__move__line__pb2


class StockMoveLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StockMoveLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineCreate",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.FromString,
        )
        self.StockMoveLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineRead",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.FromString,
        )
        self.StockMoveLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineUpdate",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.FromString,
        )
        self.StockMoveLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineDelete",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.FromString,
        )


class StockMoveLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StockMoveLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockMoveLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StockMoveLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineCreate,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.SerializeToString,
        ),
        "StockMoveLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineRead,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.SerializeToString,
        ),
        "StockMoveLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineUpdate,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.SerializeToString,
        ),
        "StockMoveLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineDelete,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockMoveLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StockMoveLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineCreate",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineRead",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineUpdate",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineDelete",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
