# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/quant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/quant.proto\x12\x1fpro.omni.oms.api.v1.stock.quant\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf5\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x0c\n\x04lote\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12\x10\n\x08quantity\x18\x06 \x01(\x02\x12\x0e\n\x06uom_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xdc\x01\n\x12QuantCreateRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\x05\x12\x13\n\x0blocation_id\x18\x02 \x01(\x05\x12\x0c\n\x04lote\x18\x03 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x10\n\x08quantity\x18\x05 \x01(\x02\x12\x0e\n\x06uom_id\x18\x06 \x01(\x05\x12\x19\n\x11reserved_quantity\x18\x07 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11QuantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x06quants\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\x83\x01\n\x12QuantUpdateRequest\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"X\n\x12QuantDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cQuantService\x12z\n\x0bQuantCreate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantCreateResponse"\x00\x12t\n\tQuantRead\x12\x31.pro.omni.oms.api.v1.stock.quant.QuantReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.quant.QuantReadResponse"\x00\x12z\n\x0bQuantUpdate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantUpdateResponse"\x00\x12z\n\x0bQuantDelete\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.quant_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUANT"]._serialized_start = 109
    _globals["_QUANT"]._serialized_end = 354
    _globals["_QUANTCREATEREQUEST"]._serialized_start = 357
    _globals["_QUANTCREATEREQUEST"]._serialized_end = 577
    _globals["_QUANTCREATERESPONSE"]._serialized_start = 580
    _globals["_QUANTCREATERESPONSE"]._serialized_end = 731
    _globals["_QUANTREADREQUEST"]._serialized_start = 734
    _globals["_QUANTREADREQUEST"]._serialized_end = 1100
    _globals["_QUANTREADRESPONSE"]._serialized_start = 1103
    _globals["_QUANTREADRESPONSE"]._serialized_end = 1312
    _globals["_QUANTUPDATEREQUEST"]._serialized_start = 1315
    _globals["_QUANTUPDATEREQUEST"]._serialized_end = 1446
    _globals["_QUANTUPDATERESPONSE"]._serialized_start = 1449
    _globals["_QUANTUPDATERESPONSE"]._serialized_end = 1600
    _globals["_QUANTDELETEREQUEST"]._serialized_start = 1602
    _globals["_QUANTDELETEREQUEST"]._serialized_end = 1690
    _globals["_QUANTDELETERESPONSE"]._serialized_start = 1692
    _globals["_QUANTDELETERESPONSE"]._serialized_end = 1788
    _globals["_QUANTSERVICE"]._serialized_start = 1791
    _globals["_QUANTSERVICE"]._serialized_end = 2295
# @@protoc_insertion_point(module_scope)
