# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_warehouse_pb2 as v1_dot_rules_dot_delivery__warehouse__pb2


class DeliveryWarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryWarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseCreate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.FromString,
        )
        self.DeliveryWarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseRead",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.FromString,
        )
        self.DeliveryWarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseUpdate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.FromString,
        )
        self.DeliveryWarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseDelete",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.FromString,
        )


class DeliveryWarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryWarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryWarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryWarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseCreate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRead,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.SerializeToString,
        ),
        "DeliveryWarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.SerializeToString,
        ),
        "DeliveryWarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseDelete,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryWarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryWarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseCreate",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseRead",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseUpdate",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseDelete",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
