# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_category_pb2 as v1_dot_rules_dot_delivery__category__pb2


class DeliveryCategoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryCategoryCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryCreate",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.FromString,
        )
        self.DeliveryCategoryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryRead",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.FromString,
        )
        self.DeliveryCategoryUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryUpdate",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.FromString,
        )
        self.DeliveryCategoryDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryDelete",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.FromString,
        )


class DeliveryCategoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryCategoryCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryCategoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryCategoryCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCreate,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.SerializeToString,
        ),
        "DeliveryCategoryRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryRead,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.SerializeToString,
        ),
        "DeliveryCategoryUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.SerializeToString,
        ),
        "DeliveryCategoryDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryDelete,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryCategoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryCategoryCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryCreate",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryRead",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryUpdate",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryDelete",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
