# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import document_type_pb2 as v1_dot_utilities_dot_document__type__pb2


class DocumentTypeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DocumentTypeAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeAdd",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.FromString,
        )
        self.DocumentTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeRead",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.FromString,
        )
        self.DocumentTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeUpdate",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.FromString,
        )
        self.DocumentTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeDelete",
            request_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.FromString,
        )


class DocumentTypeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DocumentTypeAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DocumentTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DocumentTypeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DocumentTypeAdd": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeAdd,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.SerializeToString,
        ),
        "DocumentTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeRead,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.SerializeToString,
        ),
        "DocumentTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeUpdate,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.SerializeToString,
        ),
        "DocumentTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DocumentTypeDelete,
            request_deserializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DocumentTypeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DocumentTypeAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeAdd",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeRead",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeUpdate",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DocumentTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.document_type.DocumentTypeService/DocumentTypeDelete",
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_document__type__pb2.DocumentTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
